@@ -14,10 +14,9 @@ PinyinToneMark = {
 
 
 class Pinyin:
-    """translate chinese hanzi to pinyin by python, inspired by flyerhzm’s
-    `chinese_pinyin`_ gem
+    """Translate Chinese hanzi to pinyin (拼音) by Python, 汉字转拼音
 
-    usage
+    Usage
     -----
     ::
 
@@ -41,22 +40,27 @@ class Pinyin:
         'S'
         >>> p.get_initials("上海")
         'S-H'
-        >>> p.get_initials("上海", u'')
+        >>> p.get_initials("上海", '')
         'SH'
-        >>> p.get_initials("上海", u' ')
+        >>> p.get_initials("上海", ' ')
         'S H'
-
-    请输入utf8编码汉字
-    .. _chinese_pinyin: https://github.com/flyerhzm/chinese_pinyin
+        >>> # get_initials with retroflex, #39
+        >>> p.get_initials("上海", splitter='-', with_retroflex=True)
+        'SH-H'
+        >>> # get combinations of the multiple readings of the characters
+        >>> p.get_pinyins('模型', splitter=' ', tone_marks='marks')
+        ['mó xíng', 'mú xíng']
+        >>> p.get_pinyins('模样', splitter=' ', tone_marks='marks')
+        ['mó yáng', 'mó yàng', 'mó xiàng', 'mú yáng', 'mú yàng', 'mú xiàng']
     """
 
     data_path = Path(__file__).resolve().with_name('Mandarin.dat')
 
-    def __init__(self, data_path=data_path):
+    def __init__(self, data_path: str = data_path) -> None:
         self.pinyins = dict(tuple(line.split('\t', maxsplit=1)) for line in data_path.read_text().splitlines())
 
     @staticmethod
-    def decode_pinyin(s):
+    def decode_pinyin(s: str) -> str:
         s = s.lower()
         r = ""
         t = ""
@@ -92,7 +96,7 @@ class Pinyin:
         return r
 
     @staticmethod
-    def convert_pinyin(word, convert):
+    def convert_pinyin(word: str, convert: str) -> str:
         if convert == 'capitalize':
             return word.capitalize()
         if convert == 'lower':
@@ -140,23 +144,15 @@ class Pinyin:
 
         return self.get_pinyins(chars, splitter=splitter, tone_marks=tone_marks, convert=convert, n=1)[0]
 
-    def get_initial(self, char='你'):
+    def get_initial(self, char: str, with_retroflex: bool = False) -> str:
         try:
-            return self.pinyins[f"{ord(char):X}"].split(" ")[0][0]
+            first_pinyin = self.pinyins[f"{ord(char):X}"].split(" ")[0]
+            if with_retroflex and (first_pinyin[:2] in ('ZH', 'CH', 'SH')):
+                return first_pinyin[:2]
+            else:
+                return first_pinyin[0]
         except KeyError:
             return char
 
-    def get_initials(self, chars='你好', splitter='-'):
-        result = []
-        flag = 1
-        for char in chars:
-            try:
-                result.append(self.pinyins[f"{ord(char):X}"].split(" ")[0][0])
-                flag = 1
-            except KeyError:
-                if flag:
-                    result.append(char)
-                else:
-                    result[-1] += char
-
-        return splitter.join(result)
+    def get_initials(self, chars: str, splitter: str = '-', with_retroflex: bool = False):
+        return splitter.join([self.get_initial(char, with_retroflex=with_retroflex) for char in chars])
